#! /bin/sh
#+
# NAME
# ====
#
# ircaam_profile.sh - define IRCAAM environment
#
# SYNOPSIS
# ========
#
# Online usage
# ::
#
# $ . ./ircaam_profile.sh -d directory -i indir -o outdir -t tempdir
#
# In ${HOME}/.profile, add the following line
# ::
#
#  . ircaam_profile.sh -d directory  -i indir -o outdir -t tempdir
#
# DESCRIPTION
# ===========
#
# define IRCAAM environment
#
# ${IRCAAM} is the source base directory of tools.
#
# ${IRCAAM_LOG} is the directory where log files  will be written.
#
# ${IRCAAM_ID} is the directory where input files must be.
#
# ${IRCAAM_OD} is the directory where output files will be written.
#
# ${IRCAAM}/../bin/ is added to PATH.
#
# MANPATH++
#
# SEE ALSO
# ========
#
# for matlab/octave environment :
#
# ircaam_startup.m_
#
# .. _ircaam_startup.m : ircaam_startup.m.html
#
# EXAMPLES
# ========
#
# For fplod, on aedon.locean-ipsl.upmc.fr:
#
# ::
#
#  $ cd /usr/home/fplod/incas/ircaam/ircaam_ws/src/
#  $ . ./ircaam_profile.sh \
#    -d $(pwd) \
#    -i /usr/temp/${LOGNAME}/ircaam_d/ \
#    -o /usr/temp/${LOGNAME}/ircaam_d/ \
#    -t /usr/temp/${LOGNAME}/log/
#
# For fplod on zeus.locean-ipsl.umpc.fr:
#
# ::
#
#  $ cd ${HOME}/incas/ircaam/ircaam_ws/src/
#  $ . ./ircaam_profile.sh \
#    -d $(pwd) \
#    -i /usr/temp/${LOGNAME}/ircaam_d/ \
#    -o /usr/temp/${LOGNAME}/ircaam_d/ \
#    -t /usr/temp/${LOGNAME}/log/
#
# FILES
# =====
#
# original location
# ~~~~~~~~~~~~~~~~~
#
# /usr/home/fplod/incas/ircaam/ircaam_ws/src/ircaam_profile.sh sur aedon.locean-ipsl.upmc.fr
#
#
# TODO
# ====
#
#
# EVOLUTIONS
# ==========
#
# ++ option bavarde
#
# ++ machine dependant
#
# ++ besoin de posix
#
# ++ pas de MANPATH defini par dfaut sur zeus
#
# ++ climserv
#
# $Id$
#
# - fplod 2009-02-17T11:59:35Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#  * more unset statements
#
# - fplod 2009-02-04T13:35:30Z zeus.locean-ipsl.upmc.fr (Linux)
#
#  * ${IRCAAM}/../bin/ is added to PATH.
#
# - fplod 2008-08-14T12:28:16Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#  * move all \*.sh and \*.pro files to src/
#
# - fplod 2008-07-21T10:58:47Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * creation
#
#-
system=$(uname)
case "${system}" in
 AIX|IRIX64)
  echo " www : no specific posix checking"
 ;;
 *)
  set -o posix
 ;;
esac
unset system
#
LANG=POSIX
#
# as this script might be launch in .profile, command is forced.
command=ircaam_profile.sh
#
usage=" Usage : ${command} -d directory -i indir -o outdir -t tempdir"
#
while [ ! -z "${1}" ] # ++ pb bash
do
 case ${1} in
 -d) # directory for application choosen by user (see svn checkout command used)
  directory=${2}
  shift
 ;;
 -i) # directory for inputs choosen by user
  indir=${2}
  shift
 ;;
 -o) # directory for outputs choosen by user
  outdir=${2}
  shift
 ;;
 -t) # directory for temporary outputs choosen by user
  tempdir=${2}
  shift
 ;;
 *) # other choice
  echo "${usage}"
  # nb : no exit because this file should be launched by login process
 ;;
 esac
 shift # next flag
done
#
unset usage
#
# check for ${directory}
if [ ! -d ${directory} ]
then
 echo " eee : ${directory} not found"
 # nb : no exit because this file should be launched by login process
fi
#
# check for permission on directory
if [ ! -x ${directory} ]
then
 echo " eee : ${directory} not reachable"
 # nb : no exit because this file should be launched by login process
fi
#
set -u
#
IRCAAM=${directory}
export IRCAAM
unset directory
#
# add IRCAAM tools to PATH
# if not already done
echo ${PATH} | grep -q ${IRCAAM}
test_path=${?}
if [ ${test_path} -ne 0 ]
then
   PATH=${IRCAAM}/:${PATH}
   export PATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${IRCAAM}/ already in \${PATH}"
fi
unset test_path
#
# add IRCAAM manuals to MANPATH
# if not already done
echo ${MANPATH} | grep -q ${IRCAAM}
test_manpath=${?}
if [ ${test_manpath} -ne 0 ]
then
   MANPATH=${IRCAAM}/man/:${MANPATH}
   export MANPATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${IRCAAM}/man/ already in \${MANPATH}"
fi
unset test_manpath
#
# add ${IRCAAM}/../bin tools to PATH
# if not already done
echo ${PATH} | grep -q "${IRCAAM}/../bin"
test_path=${?}
if [ ${test_path} -ne 0 ]
then
   PATH=${IRCAAM}/../bin/:${PATH}
   export PATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${IRCAAM}/../bin/ already in \${PATH}"
fi
unset test_path
#
IRCAAM_LOG=${tempdir}
export IRCAAM_LOG
unset tempdir
if [ ! -d ${IRCAAM_LOG} ]
then
  mkdir -p ${IRCAAM_LOG}
  echo "${command} : iii : creation of \${IRCAAM_LOG}"
fi
# check for permission on IRCAAM_LOG
if [ ! -x ${IRCAAM_LOG} ]
then
 echo " eee : ${IRCAAM_LOG} not reachable"
 # nb : no exit because this file should be launched by login process
fi
#
# check for permission on IRCAAM_LOG
if [ ! -w ${IRCAAM_LOG} ]
then
 echo " eee : ${IRCAAM_LOG} not writable"
 # nb : no exit because this file shouldreachable be launched by login process
fi
#
EDITOR=vi
export EDITOR
#
# io directories
IRCAAM_ID=${indir}
export IRCAAM_ID
unset indir
if [ ! -d ${IRCAAM_ID} ]
then
  mkdir -p ${IRCAAM_ID}
  echo "${command} : iii : creation of \${IRCAAM_ID}"
fi
# check for permission on IRCAAM_ID
if [ ! -x ${IRCAAM_ID} ]
then
 echo " eee : ${IRCAAM_ID} not reachable"
 # nb : no exit because this file should be launched by login process
fi
#
IRCAAM_OD=${outdir}
export IRCAAM_OD
unset outdir
if [ ! -d ${IRCAAM_OD} ]
then
  mkdir -p ${IRCAAM_OD}
  echo "${command} : iii : creation of \${IRCAAM_OD}"
fi
# check for permission on IRCAAM_OD
if [ ! -x ${IRCAAM_OD} ]
then
 echo " eee : ${IRCAAM_OD} not reachable"
 # nb : no exit because this file should be launched by login process
fi
if [ ! -w ${IRCAAM_OD} ]
then
 echo " eee : ${IRCAAM_OD} not writable"
 # nb : no exit because this file should be launched by login process
fi
#
#
unset command
#
# end
# nb : no exit because this file should be launched by login process
